@@ -11,16 +11,18 @@ class RouteHandler(APIHandler):
     # Jupyter server
     @tornado.web.authenticated
     def get(self):
-        f = open(os.path.expanduser("~/.ssh/id_rsa.pub"), "r")
+        ssh = open(os.path.expanduser("~/.ssh/id_rsa.pub"), "r")
+        rsa = open(os.path.expanduser("~/.ssh/id_rsa.p8"), "r")
         self.finish(json.dumps({
-            "data": f.read()
+            "ssh": ssh.read(),
+            "rsa": rsa.read()
         }))
 
 def setup_handlers(web_app):
-    print("got inside setup handlers")
     host_pattern = ".*$"
 
     base_url = web_app.settings["base_url"]
     route_pattern = url_path_join(base_url, "getsshpubkey", "get_ssh_pub_key")
+    
     handlers = [(route_pattern, RouteHandler)]
     web_app.add_handlers(host_pattern, handlers)
